Badges
------

Badges point to the current status of the different Continuous Integration tools
in the ``master`` branch. You can also configure badges to report on other
branches, though. Are tests passing? Is the package building properly? Is
documentation building properly? What is the quality of the code? Red lights
mean something is wrong and you should attend it shortly!

Each platform provide their own badges, and you can modify and emulate the badge
strategy in the ``README.rst`` file. Yet, you can further tune the badges style
by creating your own personalized badge with `Shields.io`_.

You have noticed already that there is no badge for PyPI. That is because
"pysidetap" is deployed at ``test.pypi.org``. You will find also
at Shields.io how to add the PyPI badge.

.. _Shields.io: https://shields.io/
